BlobContainerClient

Struct BlobContainerClient 

pub struct BlobContainerClient { /* private fields */ }

Implementations

Source

impl BlobContainerClient

pub fn new( container_url: Url, credential: Option<Arc<dyn TokenCredential>>, options: Option<BlobContainerClientOptions>, ) -> Result<Self>

Creates a new BlobContainerClient from a container URL.

Arguments
  • container_url - The full URL of the container, for example https://myaccount.blob.core.windows.net/mycontainer. The caller is responsible for percent-encoding the URL correctly; it will be used as-is.
  • credential - An optional implementation of TokenCredential that can provide an Entra ID token to use when authenticating.
  • options - Optional configuration for the client.
pub fn blob_client(&self, blob_name: &str) -> BlobClient

Returns a new instance of BlobClient.

Arguments
  • blob_name - The name of the blob.
pub fn url(&self) -> &Url

Gets the URL of the container.

pub async fn exists(&self) -> Result<bool>

Checks if the container exists.

Returns true if the container exists, false if the container does not exist, and propagates all other errors.

Source

impl BlobContainerClient

pub async fn acquire_lease( &self, duration: i32, options: Option<BlobContainerClientAcquireLeaseOptions<'_>>, ) -> Result<Response<BlobContainerClientAcquireLeaseResult, NoFormat>>

Requests a new lease on the specified container.

Arguments
  • duration - Specifies the duration of the lease, in seconds, or negative one (-1) for a lease that never expires. A non-infinite lease can be between 15 and 60 seconds.
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the BlobContainerClientAcquireLeaseResultHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{BlobContainerClientAcquireLeaseResult, BlobContainerClientAcquireLeaseResultHeaders};
async fn example() -> Result<()> {
    let response: Response<BlobContainerClientAcquireLeaseResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    if let Some(lease_id) = response.lease_id()? {
        println!("x-ms-lease-id: {:?}", lease_id);
    }
    Ok(())
}
Available headers
pub async fn break_lease( &self, options: Option<BlobContainerClientBreakLeaseOptions<'_>>, ) -> Result<Response<BlobContainerClientBreakLeaseResult, NoFormat>>

Ends a lease and ensures that another client can’t acquire a new lease until the current lease period has expired.

Arguments
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the BlobContainerClientBreakLeaseResultHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{BlobContainerClientBreakLeaseResult, BlobContainerClientBreakLeaseResultHeaders};
async fn example() -> Result<()> {
    let response: Response<BlobContainerClientBreakLeaseResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    if let Some(lease_time) = response.lease_time()? {
        println!("x-ms-lease-time: {:?}", lease_time);
    }
    Ok(())
}
Available headers
pub async fn change_lease( &self, lease_id: String, proposed_lease_id: String, options: Option<BlobContainerClientChangeLeaseOptions<'_>>, ) -> Result<Response<BlobContainerClientChangeLeaseResult, NoFormat>>

Change the ID of an existing lease.

Arguments
  • lease_id - A lease ID for the resource. The resource must have an active lease and the lease ID must match.
  • proposed_lease_id - The proposed lease ID for the lease.
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the BlobContainerClientChangeLeaseResultHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{BlobContainerClientChangeLeaseResult, BlobContainerClientChangeLeaseResultHeaders};
async fn example() -> Result<()> {
    let response: Response<BlobContainerClientChangeLeaseResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    if let Some(lease_id) = response.lease_id()? {
        println!("x-ms-lease-id: {:?}", lease_id);
    }
    Ok(())
}
Available headers
pub async fn create( &self, options: Option<BlobContainerClientCreateOptions<'_>>, ) -> Result<Response<(), NoFormat>>

Creates a new container in the specified account. If the container with the same name already exists, the operation fails.

Arguments
  • options - Optional parameters for the request.
pub async fn delete( &self, options: Option<BlobContainerClientDeleteOptions<'_>>, ) -> Result<Response<(), NoFormat>>

Deletes the specified container.

Arguments
  • options - Optional parameters for the request.
pub fn find_blobs_by_tags( &self, filter_expression: &str, options: Option<BlobContainerClientFindBlobsByTagsOptions<'_>>, ) -> Result<Pager<FilteredBlobResponse, XmlFormat>>

Lists blobs in the specified container whose tags match a given search expression.

Arguments
  • filter_expression - Filters the results to return only blobs whose tags match the specified expression.
  • options - Optional parameters for the request.
pub async fn get_access_policy( &self, options: Option<BlobContainerClientGetAccessPolicyOptions<'_>>, ) -> Result<Response<SignedIdentifiers, XmlFormat>>

Gets the permissions for the specified container.

Arguments
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the SignedIdentifiersHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, XmlFormat}};
use azure_storage_blob::models::{SignedIdentifiers, SignedIdentifiersHeaders};
async fn example() -> Result<()> {
    let response: Response<SignedIdentifiers, XmlFormat> = unimplemented!();
    // Access response headers
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    if let Some(access) = response.access()? {
        println!("x-ms-blob-public-access: {:?}", access);
    }
    Ok(())
}
Available headers
pub async fn get_account_info( &self, options: Option<BlobContainerClientGetAccountInfoOptions<'_>>, ) -> Result<Response<BlobContainerClientGetAccountInfoResult, NoFormat>>

Returns information about the storage account.

Arguments
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the BlobContainerClientGetAccountInfoResultHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{BlobContainerClientGetAccountInfoResult, BlobContainerClientGetAccountInfoResultHeaders};
async fn example() -> Result<()> {
    let response: Response<BlobContainerClientGetAccountInfoResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(account_kind) = response.account_kind()? {
        println!("x-ms-account-kind: {:?}", account_kind);
    }
    if let Some(is_hierarchical_namespace_enabled) = response.is_hierarchical_namespace_enabled()? {
        println!("x-ms-is-hns-enabled: {:?}", is_hierarchical_namespace_enabled);
    }
    if let Some(sku_name) = response.sku_name()? {
        println!("x-ms-sku-name: {:?}", sku_name);
    }
    Ok(())
}
Available headers
pub async fn get_properties( &self, options: Option<BlobContainerClientGetPropertiesOptions<'_>>, ) -> Result<Response<BlobContainerClientGetPropertiesResult, NoFormat>>

Returns all user-defined metadata and system properties for the specified container. The data returned does not include the container’s list of blobs.

Arguments
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the BlobContainerClientGetPropertiesResultHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{BlobContainerClientGetPropertiesResult, BlobContainerClientGetPropertiesResultHeaders};
async fn example() -> Result<()> {
    let response: Response<BlobContainerClientGetPropertiesResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    if let Some(access) = response.access()? {
        println!("x-ms-blob-public-access: {:?}", access);
    }
    Ok(())
}
Available headers
pub fn list_blobs( &self, options: Option<BlobContainerClientListBlobsOptions<'_>>, ) -> Result<Pager<ListBlobsResponse, XmlFormat>>

Returns a list of the blobs in the specified container.

Arguments
  • options - Optional parameters for the request.
pub async fn release_lease( &self, lease_id: String, options: Option<BlobContainerClientReleaseLeaseOptions<'_>>, ) -> Result<Response<BlobContainerClientReleaseLeaseResult, NoFormat>>

Frees the lease if it’s no longer needed, so that another client can immediately acquire a lease against the container.

Arguments
  • lease_id - A lease ID for the resource. The resource must have an active lease and the lease ID must match.
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the BlobContainerClientReleaseLeaseResultHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{BlobContainerClientReleaseLeaseResult, BlobContainerClientReleaseLeaseResultHeaders};
async fn example() -> Result<()> {
    let response: Response<BlobContainerClientReleaseLeaseResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    Ok(())
}
Available headers
pub async fn renew_lease( &self, lease_id: String, options: Option<BlobContainerClientRenewLeaseOptions<'_>>, ) -> Result<Response<BlobContainerClientRenewLeaseResult, NoFormat>>

Renews an existing lease.

Arguments
  • lease_id - A lease ID for the resource. The resource must have an active lease and the lease ID must match.
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the BlobContainerClientRenewLeaseResultHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{BlobContainerClientRenewLeaseResult, BlobContainerClientRenewLeaseResultHeaders};
async fn example() -> Result<()> {
    let response: Response<BlobContainerClientRenewLeaseResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    if let Some(lease_id) = response.lease_id()? {
        println!("x-ms-lease-id: {:?}", lease_id);
    }
    Ok(())
}
Available headers
pub async fn set_access_policy( &self, container_acl: RequestContent<SignedIdentifiers, XmlFormat>, options: Option<BlobContainerClientSetAccessPolicyOptions<'_>>, ) -> Result<Response<(), NoFormat>>

Sets the permissions for the specified container.

Arguments
  • container_acl - The access control list for the container.
  • options - Optional parameters for the request.
pub async fn set_metadata( &self, metadata: &HashMap<String, String>, options: Option<BlobContainerClientSetMetadataOptions<'_>>, ) -> Result<Response<(), NoFormat>>

Sets user-defined metadata for the specified container.

Arguments
  • metadata - The metadata headers.
  • options - Optional parameters for the request.