PageBlobClient

Struct PageBlobClient 

pub struct PageBlobClient { /* private fields */ }

Implementations

Source

impl PageBlobClient

pub fn new( blob_url: Url, credential: Option<Arc<dyn TokenCredential>>, options: Option<PageBlobClientOptions>, ) -> Result<Self>

Creates a new PageBlobClient from a blob URL.

Arguments
  • blob_url - The full URL of the Page blob, for example https://myaccount.blob.core.windows.net/mycontainer/myblob. The caller is responsible for percent-encoding the URL correctly; it will be used as-is.
  • credential - An optional implementation of TokenCredential that can provide an Entra ID token to use when authenticating.
  • options - Optional configuration for the client.
pub fn url(&self) -> &Url

Gets the URL of the blob.

Source

impl PageBlobClient

pub async fn clear_pages( &self, range: HttpRange, options: Option<PageBlobClientClearPagesOptions<'_>>, ) -> Result<Response<PageBlobClientClearPagesResult, NoFormat>>

Clears a range of pages from the specified page blob.

Arguments
  • range - Specifies the range of the blob to operate on.
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the PageBlobClientClearPagesResultHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{PageBlobClientClearPagesResult, PageBlobClientClearPagesResultHeaders};
async fn example() -> Result<()> {
    let response: Response<PageBlobClientClearPagesResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(content_md5) = response.content_md5()? {
        println!("content-md5: {:?}", content_md5);
    }
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    Ok(())
}
Available headers
pub async fn create( &self, size: u64, options: Option<PageBlobClientCreateOptions<'_>>, ) -> Result<Response<PageBlobClientCreateResult, NoFormat>>

Creates a new page blob.

Arguments
  • size - The maximum size for the page blob. Must be aligned to a 512-byte boundary.
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the PageBlobClientCreateResultHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{PageBlobClientCreateResult, PageBlobClientCreateResultHeaders};
async fn example() -> Result<()> {
    let response: Response<PageBlobClientCreateResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(content_md5) = response.content_md5()? {
        println!("content-md5: {:?}", content_md5);
    }
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    Ok(())
}
Available headers
pub fn list_page_ranges( &self, options: Option<PageBlobClientListPageRangesOptions<'_>>, ) -> Result<PageIterator<Response<PageList, XmlFormat>>>

Returns the list of valid page ranges for the specified page blob.

Arguments
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the PageListHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, XmlFormat}};
use azure_storage_blob::models::{PageList, PageListHeaders};
async fn example() -> Result<()> {
    let response: Response<PageList, XmlFormat> = unimplemented!();
    // Access response headers
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    if let Some(blob_content_length) = response.blob_content_length()? {
        println!("x-ms-blob-content-length: {:?}", blob_content_length);
    }
    Ok(())
}
Available headers
pub async fn resize( &self, size: u64, options: Option<PageBlobClientResizeOptions<'_>>, ) -> Result<Response<PageBlobClientResizeResult, NoFormat>>

Changes the size of the specified page blob.

Arguments
  • size - The maximum size for the page blob. Must be aligned to a 512-byte boundary.
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the PageBlobClientResizeResultHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{PageBlobClientResizeResult, PageBlobClientResizeResultHeaders};
async fn example() -> Result<()> {
    let response: Response<PageBlobClientResizeResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    if let Some(blob_sequence_number) = response.blob_sequence_number()? {
        println!("x-ms-blob-sequence-number: {:?}", blob_sequence_number);
    }
    Ok(())
}
Available headers
pub async fn set_sequence_number( &self, sequence_number_action: SequenceNumberActionType, options: Option<PageBlobClientSetSequenceNumberOptions<'_>>, ) -> Result<Response<PageBlobClientSetSequenceNumberResult, NoFormat>>

Updates the sequence number of the specified page blob. The operation will fail if the specified sequence number is less than the current sequence number of the blob.

Arguments
  • sequence_number_action - Required if the blob sequence number is provided. This property indicates how the service should modify the blob’s sequence number.
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the PageBlobClientSetSequenceNumberResultHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{PageBlobClientSetSequenceNumberResult, PageBlobClientSetSequenceNumberResultHeaders};
async fn example() -> Result<()> {
    let response: Response<PageBlobClientSetSequenceNumberResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    if let Some(blob_sequence_number) = response.blob_sequence_number()? {
        println!("x-ms-blob-sequence-number: {:?}", blob_sequence_number);
    }
    Ok(())
}
Available headers
pub async fn upload_pages( &self, body: RequestContent<Bytes, NoFormat>, content_length: u64, range: HttpRange, options: Option<PageBlobClientUploadPagesOptions<'_>>, ) -> Result<Response<PageBlobClientUploadPagesResult, NoFormat>>

Writes a range of pages to the specified page blob.

Arguments
  • body - The body of the request.
  • content_length - The length of the request.
  • range - Specifies the range of the blob to operate on.
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the PageBlobClientUploadPagesResultHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{PageBlobClientUploadPagesResult, PageBlobClientUploadPagesResultHeaders};
async fn example() -> Result<()> {
    let response: Response<PageBlobClientUploadPagesResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(content_md5) = response.content_md5()? {
        println!("content-md5: {:?}", content_md5);
    }
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    Ok(())
}
Available headers
pub async fn upload_pages_from_url( &self, source_url: String, source_range: HttpRange, content_length: u64, range: HttpRange, options: Option<PageBlobClientUploadPagesFromUrlOptions<'_>>, ) -> Result<Response<PageBlobClientUploadPagesFromUrlResult, NoFormat>>

Writes a range of pages to the specified page blob where the contents are read from a URL.

Arguments
  • source_url - Specifies the URL of the source.
  • source_range - Specifies the bytes of the source.
  • content_length - The length of the request.
  • range - Specifies the range of the blob to operate on.
  • options - Optional parameters for the request.
Response Headers

The returned Response implements the PageBlobClientUploadPagesFromUrlResultHeaders trait, which provides access to response headers. For example:

use azure_core::{Result, http::{Response, NoFormat}};
use azure_storage_blob::models::{PageBlobClientUploadPagesFromUrlResult, PageBlobClientUploadPagesFromUrlResultHeaders};
async fn example() -> Result<()> {
    let response: Response<PageBlobClientUploadPagesFromUrlResult, NoFormat> = unimplemented!();
    // Access response headers
    if let Some(content_md5) = response.content_md5()? {
        println!("content-md5: {:?}", content_md5);
    }
    if let Some(etag) = response.etag()? {
        println!("etag: {:?}", etag);
    }
    if let Some(last_modified) = response.last_modified()? {
        println!("last-modified: {:?}", last_modified);
    }
    Ok(())
}
Available headers